@@ -399,13 +399,12 @@ class schemawiz:
 	def loadcsvfile(self,csvfilename):
 		if csvfilename != '':
 			try:
-				f = open(csvfilename,'r')
-				filedata = f.readlines()
-				f.close()
-				self.csvfilename = csvfilename
-				self.delimiter = self.GuessDelimiter(filedata[0])
+				with open(csvfilename) as f:
+					for csvline in f:
+						self.csvfilename = csvfilename
+						self.delimiter = self.GuessDelimiter(csvline)
+						break
 
-				#self.analyze_csvfile()
 			except Exception as e:
 				print('Cannot read file: ' + csvfilename)
 				sys.exit(0)
@@ -442,7 +441,7 @@ class schemawiz:
 							self.datalinesize = total_linesize/10
 
 						self.SomeFileContents.append(line)
-						if (linecount>1000):
+						if (linecount>100):
 							break
 				
 				#self.logger('file has ' + str(len(self.SomeFileContents)) + ' lines')
@@ -665,18 +664,25 @@ class schemawiz:
 		if self.force_delimiter != '':
 			delimiter_guess = self.force_delimiter
 		else:
-			hdrs = first_row 
-			chars_in_hdr = {}
-			chars_in_hdr = self.count_chars(hdrs,"'"+ 'abcdefghijklmnopqrstuvwxyz1234567890ABCDEFGHIJKLMNOPQRSTUVWXYZ"')
+			if first_row.find('\t') > -1:
+				delimiter_guess = '\t'
+			elif first_row.find(',') > -1:
+				delimiter_guess = ','
+			elif first_row.find('~') > -1:
+				delimiter_guess = '~'
+			else:
+				hdrs = first_row 
+				chars_in_hdr = {}
+				chars_in_hdr = self.count_chars(hdrs,"'"+ 'abcdefghijklmnopqrstuvwxyz1234567890ABCDEFGHIJKLMNOPQRSTUVWXYZ"')
 
-			currentchar = 'no idea'
-			currentvalue = 0
-			for ch in chars_in_hdr:
-				if chars_in_hdr[ch] > currentvalue:
-					currentchar = ch
-					currentvalue = chars_in_hdr[ch]
+				currentchar = 'no idea'
+				currentvalue = 0
+				for ch in chars_in_hdr:
+					if chars_in_hdr[ch] > currentvalue:
+						currentchar = ch
+						currentvalue = chars_in_hdr[ch]
 
-			delimiter_guess = currentchar
+				delimiter_guess = currentchar
 
 		return delimiter_guess
 
@@ -784,7 +790,7 @@ class schemawiz:
 		return sql
 
 	def guess_postgres_ddl(self,usetablename=''):
-
+		
 		self.dbthings.connect_local_db(database_type.Postgres)
 
 		if not self.analyzed:
@@ -797,8 +803,9 @@ class schemawiz:
 		self.lastcall_tablename = tablename
 
 		fldcommentsql = '' 
+		sql = 'DROP TABLE IF EXISTS ' + tablename + ';\n'
 
-		sql = 'CREATE TABLE IF NOT EXISTS ' + tablename + '(\n'
+		sql += 'CREATE TABLE IF NOT EXISTS ' + tablename + '(\n'
 		for i in range(0,len(self.column_names)):
 			sql += '\t' + self.column_names[i] + ' ' + self.column_datatypes[i] + ' \t\t/* eg. ' + self.column_sample[i] + ' */ ,\n'
 			if self.column_datatypes[i].strip().lower() == 'date' or self.column_datatypes[i].strip().lower() == 'timestamp':
@@ -807,6 +814,7 @@ class schemawiz:
 		sql = sql[:-2] + '\n);\n\n'
 		sql += 'COMMENT ON TABLE ' + tablename + " IS 'This Postgres table was defined by schemawiz for loading the csv file " + self.csvfilename + ", delimiter (" + self.delimiter + ")';\n"
 		sql += fldcommentsql
+		#print(sql)
 
 		return sql
 
@@ -821,7 +829,9 @@ class schemawiz:
 			tablename = usetablename
 		self.lastcall_tablename = tablename
 
-		sql = 'CREATE TABLE IF NOT EXISTS ' + tablename + '(\n'
+		sql = 'DROP TABLE IF EXISTS ' + tablename + ';\n'
+
+		sql += 'CREATE TABLE IF NOT EXISTS ' + tablename + '(\n'
 		for i in range(0,len(self.column_names)):
 			sql += '\t' + self.column_names[i] + ' ' + str(self.column_datatypes[i]) + ' \t\t/* eg. ' + self.column_sample[i] + ' */ '
 			if str(self.column_datatypes[i]).strip().lower() == 'date' or str(self.column_datatypes[i]).strip().lower() == 'timestamp':
@@ -836,17 +846,23 @@ class schemawiz:
 
 
 if __name__ == '__main__':
-	csvfilename = input('csvfile to read? ')
+	csvfilename ='station_years.tsv' #input('csvfile to read? ')
 
 	obj = schemawiz()
-
+	#obj.force_delimiter = '\t'
+	#obj.loadcsvfile(csvfilename)
+	#obj.createload_postgres_from_csv(csvfilename,'canweather.station_years','z.canweather.station_years.ddl')
+	
+	#print("delimiter= '" + obj.delimiter + "' ")
+		
+	#ddl = obj.guess_postgres_ddl('canweather.station_events')
+	
+"""
 	print('/* Postgres DDL - BEGIN ----- schemawiz().guess_postgres_ddl() ----- */ \n')
 	ddl = obj.guess_postgres_ddl(csvfilename.replace('.','_'))
 	print('/* Tablename used : ' + obj.lastcall_tablename + ' */ \n')
 	print(ddl)
 	print('/* Postgres DDL - END   ----- ----- ----- ----- */ \n')
-
-"""
 	
 	
 	print(obj.dbthings.postgres_db.does_table_exist('newtbl'))
